@@ -31,15 +31,17 @@ pub fn count_all(watch_dir: &Path) -> Result<Count> {
         .map(|file| match file {
             Ok(p) => {
                 let account = parse_account(&p, watch_dir);
-                let re = Regex::new(r"\(\^A2=(?P<count>\d+)\)").unwrap();
+                let re = Regex::new(r"\(\^A2=(?P<count>[[:xdigit:]]+)\)").unwrap();
                 let contents = std::fs::read_to_string(p).expect("could not read file");
                 let count = re.captures_iter(&contents).map(|cap| cap["count"].to_string()).last();
 
                 // If a None was returned, some accounts names might not be caught later on.
-                if count.is_some() {
-                    count.map(|c| (account, c.parse().ok().unwrap_or(0)))
-                } else {
-                    Some((account, 0))
+                match count {
+                    Some(string) => {
+                        let count = usize::from_str_radix(&string, 16).unwrap_or(0);
+                        Some((account, count))
+                    }
+                    None => Some((account, 0)),
                 }
             }
             Err(_) => None,
@@ -48,19 +50,15 @@ pub fn count_all(watch_dir: &Path) -> Result<Count> {
         .flatten()
         .collect();
 
-    let mut accounts: HashMap<String, Vec<usize>> = HashMap::new();
+    let mut accounts: HashMap<String, usize> = HashMap::new();
 
     for (account, count) in counts {
-        if let Some(bucket) = accounts.get_mut(&account) {
-            bucket.push(count);
-        } else {
-            let bucket = vec![count];
-            accounts.insert(account, bucket);
-        }
+        let current = accounts.entry(account).or_insert(0);
+        *current += count;
     }
 
-    let mut accounts: Vec<(String, usize)> = accounts.into_iter().map(|x| (x.0, x.1.iter().sum())).collect();
-    accounts.sort_by(|a, b| a.0.partial_cmp(&b.0).unwrap());
+    let mut accounts: Vec<(String, usize)> = accounts.into_iter().collect();
+    accounts.sort_by(|a, b| a.0.cmp(&b.0));
 
     Ok(Count {
         list: accounts.into_iter().map(|x| x.1).collect(),
